summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAaron Plattner <aplattner@nvidia.com>2012-06-16 14:04:37 -0700
committerAaron Plattner <aplattner@nvidia.com>2012-06-16 14:04:37 -0700
commit0ddc1c54f770fd9a91a75fcc99a74296ae9cda0f (patch)
tree8b16eb9f9b503004bc83e8c511058c3ff5ca2c62
parent6ca7e688e59d5cb5c472369a50c317443c93c834 (diff)
302.17302.17
-rw-r--r--nvidia-xconfig.1.m44
-rw-r--r--nvidia-xconfig.c12
-rw-r--r--nvidia-xconfig.h7
-rw-r--r--option_table.h30
-rw-r--r--options.c64
-rw-r--r--version.mk2
6 files changed, 42 insertions, 77 deletions
diff --git a/nvidia-xconfig.1.m4 b/nvidia-xconfig.1.m4
index b3c8e34..0914700 100644
--- a/nvidia-xconfig.1.m4
+++ b/nvidia-xconfig.1.m4
@@ -69,8 +69,8 @@ __OPTIONS__
Reads an existing X config file and adapts it to use the NVIDIA driver.
If no X config file can be found, a new one is created at /etc/X11/XF86Config with default settings.
.TP
-.B nvidia-xconfig \-\-post\-tree \-\-twinview
-Reads the existing X configuration file, adds the TwinView option, and then prints the resulting config file to standard out in tree form.
+.B nvidia-xconfig \-\-post\-tree \-\-metamode\-orientation=clone
+Reads the existing X configuration file, adds the MetaModeOrientation option, and then prints the resulting config file to standard out in tree form.
The configuration file is not modified.
.TP
.B nvidia-xconfig \-\-enable\-all\-gpus
diff --git a/nvidia-xconfig.c b/nvidia-xconfig.c
index afd4cdf..7cda22a 100644
--- a/nvidia-xconfig.c
+++ b/nvidia-xconfig.c
@@ -556,12 +556,12 @@ static void parse_commandline(Options *op, int argc, char *argv[])
op->extract_edids_output_file = strval;
break;
- case TWINVIEW_XINERAMA_INFO_ORDER_OPTION:
- op->twinview_xinerama_info_order =
+ case NVIDIA_XINERAMA_INFO_ORDER_OPTION:
+ op->nvidia_xinerama_info_order =
disable ? NV_DISABLE_STRING_OPTION : strval;
break;
- case TWINVIEW_ORIENTATION_OPTION:
+ case METAMODE_ORIENTATION_OPTION:
{
const char* valid_values[] = {
"RightOf",
@@ -574,7 +574,7 @@ static void parse_commandline(Options *op, int argc, char *argv[])
int i;
if (disable) {
- op->twinview_orientation = NV_DISABLE_STRING_OPTION;
+ op->metamode_orientation = NV_DISABLE_STRING_OPTION;
break;
}
@@ -584,12 +584,12 @@ static void parse_commandline(Options *op, int argc, char *argv[])
}
if (!valid_values[i]) {
- fprintf(stderr, "Invalid TwinViewOrientation option: "
+ fprintf(stderr, "Invalid MetaModeOrientation option: "
"\"%s\".\n", strval);
goto fail;
}
- op->twinview_orientation = strval;
+ op->metamode_orientation = strval;
}
break;
diff --git a/nvidia-xconfig.h b/nvidia-xconfig.h
index 99402e2..01521da 100644
--- a/nvidia-xconfig.h
+++ b/nvidia-xconfig.h
@@ -42,10 +42,9 @@
#define NO_POWER_CONNECTOR_CHECK_BOOL_OPTION 8
#define ALLOW_GLX_WITH_COMPOSITE_BOOL_OPTION 10
#define RANDR_ROTATION_BOOL_OPTION 11
-#define TWINVIEW_BOOL_OPTION 12
#define SEPARATE_X_SCREENS_BOOL_OPTION 13
#define XINERAMA_BOOL_OPTION 14
-#define NO_TWINVIEW_XINERAMA_INFO_BOOL_OPTION 15
+#define NVIDIA_XINERAMA_INFO_BOOL_OPTION 15
#define NOFLIP_BOOL_OPTION 16
#define DAC_8BIT_BOOL_OPTION 17
#define USE_EDID_FREQS_BOOL_OPTION 18
@@ -140,9 +139,9 @@ typedef struct __options {
char *nvidia_cfg_path;
char *extract_edids_from_file;
char *extract_edids_output_file;
- char *twinview_xinerama_info_order;
+ char *nvidia_xinerama_info_order;
char *logo_path;
- char *twinview_orientation;
+ char *metamode_orientation;
char *use_display_device;
char *custom_edid;
char *tv_standard;
diff --git a/option_table.h b/option_table.h
index e2e627d..4089f15 100644
--- a/option_table.h
+++ b/option_table.h
@@ -34,9 +34,9 @@
#define QUERY_GPU_INFO_OPTION 21
#define EXTRACT_EDIDS_OUTPUT_FILE_OPTION 22
#define MULTI_GPU_OPTION 23
-#define TWINVIEW_XINERAMA_INFO_ORDER_OPTION 24
+#define NVIDIA_XINERAMA_INFO_ORDER_OPTION 24
#define LOGO_PATH_OPTION 25
-#define TWINVIEW_ORIENTATION_OPTION 26
+#define METAMODE_ORIENTATION_OPTION 26
#define VIRTUAL_OPTION 27
#define USE_DISPLAY_DEVICE_OPTION 28
#define CUSTOM_EDID_OPTION 29
@@ -521,7 +521,7 @@ static const NVGetoptOption __options[] = {
NVGETOPT_INTEGER_ARGUMENT | NVGETOPT_ALLOW_DISABLE, NULL,
"Enable or disable the stereo mode. Valid values for &STEREO& are: 0 "
"(Disabled), 1 (DDC glasses), 2 (Blueline glasses), 3 (Onboard stereo), "
- "4 (TwinView clone mode stereo), 5 (SeeReal digital flat panel), 6 "
+ "4 (multi-display clone mode stereo), 5 (SeeReal digital flat panel), 6 "
"(Sharp3D digital flat panel), 7 (Arisawa/Hyundai/Zalman/Pavione/Miracube), "
"8 (3D DLP), 9 (3D DLP INV), 10 (NVIDIA 3D VISION), "
"11 (NVIDIA 3D VISION PRO)." },
@@ -550,27 +550,25 @@ static const NVGetoptOption __options[] = {
"Enable or disable the \"TVOverScan\" X configuration option. Valid "
"values are decimal values in the range 1.0 and 0.0." },
- { "twinview", XCONFIG_BOOL_VAL(TWINVIEW_BOOL_OPTION),
- NVGETOPT_IS_BOOLEAN, NULL, "Enable or disable TwinView." },
-
- { "twinview-orientation", TWINVIEW_ORIENTATION_OPTION,
+ { "metamode-orientation", METAMODE_ORIENTATION_OPTION,
NVGETOPT_STRING_ARGUMENT | NVGETOPT_ALLOW_DISABLE, "ORIENTATION",
- "Specify the TwinViewOrientation. Valid values for &ORIENTATION& are: "
+ "Specify the MetaModeOrientation. Valid values for &ORIENTATION& are: "
"\"RightOf\" (the default), \"LeftOf\", \"Above\", \"Below\", or "
"\"Clone\"." },
- { "twinview-xinerama-info",
- XCONFIG_BOOL_VAL(NO_TWINVIEW_XINERAMA_INFO_BOOL_OPTION),
+ { "nvidia-xinerama-info",
+ XCONFIG_BOOL_VAL(NVIDIA_XINERAMA_INFO_BOOL_OPTION),
NVGETOPT_IS_BOOLEAN, NULL,
- "Prohibits providing Xinerama information when in TwinView." },
+ "Enable or disable providing Xinerama information from the "
+ "NVIDIA X driver." },
- { "twinview-xinerama-info-order",
- TWINVIEW_XINERAMA_INFO_ORDER_OPTION,
+ { "nvidia-xinerama-info-order",
+ NVIDIA_XINERAMA_INFO_ORDER_OPTION,
NVGETOPT_STRING_ARGUMENT | NVGETOPT_ALLOW_DISABLE, NULL,
- "Enable or disable the \"TwinViewXineramaInfoOrder\" X configuration "
- "option. &TWINVIEW-XINERAMA-INFO-ORDER& is a comma-separated list "
+ "Enable or disable the \"nvidiaXineramaInfoOrder\" X configuration "
+ "option. &NVIDIA-XINERAMA-INFO-ORDER& is a comma-separated list "
"of display device names that describe the order in which "
- "TwinViewXineramaInfo should be reported. E.g., \"CRT, DFP, TV\"." },
+ "nvidiaXineramaInfo should be reported. E.g., \"CRT, DFP, TV\"." },
{ "ubb",
XCONFIG_BOOL_VAL(UBB_BOOL_OPTION), NVGETOPT_IS_BOOLEAN, NULL,
diff --git a/version.mk b/version.mk
index 8863143..527bb7c 100644
--- a/version.mk
+++ b/version.mk
@@ -1 +1 @@
-NVIDIA_VERSION = 302.11
+NVIDIA_VERSION = 302.17
diff --git a/options.c b/options.c
index 998b0fb..289a23b 100644
--- a/options.c
+++ b/options.c
@@ -48,9 +48,8 @@ static const NvidiaXConfigOption __options[] = {
{ THERMAL_CONFIGURATION_CHECK_BOOL_OPTION, FALSE, "ThermalConfigurationCheck" },
{ ALLOW_GLX_WITH_COMPOSITE_BOOL_OPTION, FALSE, "AllowGLXWithComposite" },
{ RANDR_ROTATION_BOOL_OPTION, FALSE, "RandRRotation" },
- { TWINVIEW_BOOL_OPTION, FALSE, "TwinView" },
{ XINERAMA_BOOL_OPTION, FALSE, "Xinerama" },
- { NO_TWINVIEW_XINERAMA_INFO_BOOL_OPTION, TRUE, "NoTwinViewXineramaInfo" },
+ { NVIDIA_XINERAMA_INFO_BOOL_OPTION, FALSE, "nvidiaXineramaInfo" },
{ NOFLIP_BOOL_OPTION, TRUE, "NoFlip" },
{ DAC_8BIT_BOOL_OPTION, FALSE, "Dac8Bit" },
{ USE_EDID_FREQS_BOOL_OPTION, FALSE, "UseEdidFreqs" },
@@ -303,32 +302,6 @@ static void set_option_value(XConfigScreenPtr screen,
/*
- * update_twinview_options() - update the TwinView options
- */
-
-static void update_twinview_options(Options *op, XConfigScreenPtr screen)
-{
- /*
- * if TwinView was specified, enable/disable the other TwinView
- * options, too
- */
-
- if (GET_BOOL_OPTION(op->boolean_options, TWINVIEW_BOOL_OPTION)) {
- remove_option(screen, "TwinViewOrientation");
- remove_option(screen, "SecondMonitorHorizSync");
- remove_option(screen, "SecondMonitorVertRefresh");
- remove_option(screen, "MetaModes");
-
- if (GET_BOOL_OPTION(op->boolean_option_values, TWINVIEW_BOOL_OPTION)) {
- set_option_value(screen, "MetaModes",
- "nvidia-auto-select, nvidia-auto-select");
- }
- }
-} /* update_twinview_options() */
-
-
-
-/*
* find_metamode_offset() - find the first metamode offset in
* 'string'; returns a pointer to the start of the offset
* specification and assigns 'end' (if non-NULL) to the first character
@@ -568,10 +541,6 @@ void update_options(Options *op, XConfigScreenPtr screen)
}
}
- /* update the TwinView-related options */
-
- update_twinview_options(op, screen);
-
/* update the Display SubSection options */
update_display_options(op, screen);
@@ -650,32 +619,31 @@ void update_options(Options *op, XConfigScreenPtr screen)
set_option_value(screen, "AcpidSocketPath", op->acpid_socket_path);
}
}
-
- /* add the twinview xinerama info order option */
-
- if (op->twinview_xinerama_info_order) {
- remove_option(screen, "TwinViewXineramaInfoOrder");
- if (op->twinview_xinerama_info_order != NV_DISABLE_STRING_OPTION) {
- set_option_value(screen, "TwinViewXineramaInfoOrder",
- op->twinview_xinerama_info_order);
+ /* add the nvidia xinerama info order option */
+
+ if (op->nvidia_xinerama_info_order) {
+ remove_option(screen, "nvidiaXineramaInfoOrder");
+ if (op->nvidia_xinerama_info_order != NV_DISABLE_STRING_OPTION) {
+ set_option_value(screen, "nvidiaXineramaInfoOrder",
+ op->nvidia_xinerama_info_order);
}
}
- /* add the twinview orientation option */
+ /* add the metamode orientation option */
- if (op->twinview_orientation) {
- remove_option(screen, "TwinViewOrientation");
- if (op->twinview_orientation != NV_DISABLE_STRING_OPTION) {
+ if (op->metamode_orientation) {
+ remove_option(screen, "MetaModeOrientation");
+ if (op->metamode_orientation != NV_DISABLE_STRING_OPTION) {
char *old_metamodes, *new_metamodes;
- set_option_value(screen, "TwinViewOrientation",
- op->twinview_orientation);
+ set_option_value(screen, "MetaModeOrientation",
+ op->metamode_orientation);
if (remove_metamode_offsets(screen,
&old_metamodes, &new_metamodes)) {
fmtwarn("The MetaModes option contained explicit offsets, "
"which would have overridden the specified "
- "TwinViewOrientation; in order to honor the "
- "requested TwinViewOrientation, the explicit offsets "
+ "MetaModeOrientation; in order to honor the "
+ "requested MetaModeOrientation, the explicit offsets "
"have been removed from the MetaModes option.\n\n"
"Old MetaModes option: \"%s\"\n"
"New MetaModes option: \"%s\".",